;----------------------------------------------------------------------------
;* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
;* Author: Sanjib Sharma                                                     *
;* Copyright (c) 2012 Sanjib Sharma                                          *
;* All rights reserved.                                                      *
;*                                                                           *
;* This file is part of EBF.  The full EBF copyright notice, including       *
;* terms governing use, modification, and redistribution, is contained in    *
;* the files COPYING and COPYRIGHT, which can be found at the root           *
;* of the source code distribution tree.                                     *
;* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
;-----------------------------------------------------------------------------
;+
; NAME:
;       EBF_GETKEYS
;
; PURPOSE:
;       This function gets the name of data objects in an ebf file as
;       a string array;
;
; DESCRIPTION:
;       This reads all keys one by one. 
;
; CALLING SEQUENCE:
;       result=ebf_getkeys(filename,[VALUES=,IT=])
;
; INPUTS:
;    filename- A string specifying the filename to read
;
; OUTPUT:
;       an array of strings
;
; KEYWORDS:
;       IT: If set will use the iterative method instaed of hashtable.
;       Values: the location of data items in file
;
; EXAMPLE:
;       IDL> result=ebf_getkeys("test.ebf")
;
; MODIFICATION HISTORY:
;       Written, 2011, Sanjib Sharma
;-




function ebf_getkeys,fname1,VALUES=Values,IT=IT
  COMPILE_OPT STRICTARR,STRICTARRSUBS
  ON_ERROR,2
  ebftable_setup,fname1,lun,dinfo,dinfo_pos,dflagswap,header,hflagswap,ecode,/RONLY
  if ecode lt 1000 then begin
     if keyword_set(IT)or(ecode ne 0) then begin
        ebftable_getkeyvalsIT,lun,keys,values            
     endif else begin
        ebftable_getkeyvalsHT,lun,dinfo,header,hflagswap,keys,values 
     endelse
  endif
  if n_elements(lun) ne 0 then free_lun,lun
  if ecode ge 1000 then message,'file not found ',fname1
  return,keys
end


;; function ebfmap_keys,filename
;;   common ebfshare,ltable
;;   if n_elements(ltable) gt 0 then begin
;;      if ltable.filename ne filename then ebfmap_load,filename
;;   endif   else ebfmap_load,filename
;;   return, ltable.name
;; end
