;----------------------------------------------------------------------------
;* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
;* Author: Sanjib Sharma                                                     *
;* Copyright (c) 2012 Sanjib Sharma                                          *
;* All rights reserved.                                                      *
;*                                                                           *
;* This file is part of EBF.  The full EBF copyright notice, including       *
;* terms governing use, modification, and redistribution, is contained in    *
;* the files COPYING and COPYRIGHT, which can be found at the root           *
;* of the source code distribution tree.                                     *
;* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
;-----------------------------------------------------------------------------
;+
; NAME:
;       EBF_INFO
;
; PURPOSE:
;       This procedure prints a summary of the  different data objects
;       in the .ebf file.
; DESCRIPTION
;       
;
; CALLING SEQUENCE:
;       ebf_info,'test.ebf'
;
; INPUTS:
;       filename: A string specifying the filename to read
;
; KEYWORDS:
;
; EXTERNAL PROGRAMS USED:
;       ebf2_header__define
; MODIFICATION HISTORY:
;       Written, 2011, Sanjib Sharma
;-





pro ebf_info,fname1,VERSION=Version
  Version='0.0.3'
  typename=['undef','char','int32','int64','float32','float64','int16','float16','struct','int8','uint8','uint16','uint32','uint64']
  typesize=[0,1,4,8,4,8,2,2,0,1,1,2,4,8]

;  typestring=[' ','a','i4','i8','f4','f8','i2','f2','struct','i1','u1','u2','u4','u8']   
  
  openr,lun,fname1,error=err,/get_lun  
  if err ne 0 then begin
     if n_elements(lun) ne 0 then free_lun,lun
     message,'file not found: '+fname1
  endif else begin
     print,'>>EBF<< Info of file: ',fname1
     print,'------------------------------------------------------------------'
     print,'name','dtype','unit','rank','dims',format='(A-20,A-10,A-10,A-5,A-20)'
     print,'------------------------------------------------------------------'


; read the header
;     ebfh={ebf2_header}
     st=0
     tot_size=0LL

     while ~EOF(lun) do begin
;        point_lun,-lun,hpos
        ebfheader_read,ebfh,lun
        point_lun,-lun,pos
;        point_lun,lun,pos+ebfh.datasize*product(ebfh.dim[0:ebfh.rank-1],/integer)
        point_lun,lun,pos+ebfh.capacity
        if ebfh.rank gt 0 then  s='('+string(ebfh.dim[0]) else s='('
        for i=1,ebfh.rank-1 do s=s+','+string(ebfh.dim[i])
        s=s+')'
  
        print,string(ebfh.name),typename[ebfh.datatype],ebfh.dataunit,strcompress(string(ebfh.rank),/remove_all),strcompress(s,/remove_all),format='(A-20,A-10,A-10,A-5,A-20)'
;        print,hpos
        if ebfh.datatype eq 8 then  begin
              print, ebfh.sdef
           ;; ind=where(ebfh.keyword eq 'sdef',count)
           ;; if count eq 1 then begin
           ;;    print, "structure definition:"
           ;;    print, ebfh.value[ind[0]]
           ;; endif
        endif   

        st++
     endwhile 
     point_lun,-lun,pos
     print,'filesize',pos,'bytes'

     free_lun,lun
     
     if st eq 0 then begin
        print,' No items found'
     endif
  endelse

end








