;----------------------------------------------------------------------------
;* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
;* Author: Sanjib Sharma                                                     *
;* Copyright (c) 2012 Sanjib Sharma                                          *
;* All rights reserved.                                                      *
;*                                                                           *
;* This file is part of EBF.  The full EBF copyright notice, including       *
;* terms governing use, modification, and redistribution, is contained in    *
;* the files COPYING and COPYRIGHT, which can be found at the root           *
;* of the source code distribution tree.                                     *
;* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
;-----------------------------------------------------------------------------
;+
; NAME:
;       
;
; PURPOSE:
;       This function reads an ebfheader of a data object from an ebf file
;
; DESCRIPTION:
;       can read version 10 and 11
;
; CALLING SEQUENCE:
;       ebfheader_read,ebfh,lun
; INPUTS:
;    ebfh- the resulting header
;    lun- the file unit appropriately positioned to the 
;         loation of the header
;
; MODIFICATION HISTORY:
;       Written, 2011, Sanjib Sharma
;-

pro ebfheader_read_V10,ebfh,lun
COMPILE_OPT STRICTARR,STRICTARRSUBS
ON_ERROR,2
  ebfh = {sig:bytarr(6),name: bytarr(100),version:bytarr(2),    $   
          extra:bytarr(36), $
          endiantest:0L,datatype:0L,  datasize:0L, rank:0L, $
	  flagswap:0L, magic4:0.0,magic3:0LL, magic5:0.0d0, $
          blocksize:0LL,dim256:lon64arr(8)}
  readu,lun,ebfh
  if ebfh.endiantest ne 256L then  begin
     swap_endian_inplace,ebfh 
     ebfh.flagswap=1
  endif   
  if ebfh.endiantest ne 256L then message,'Incorrect header format'
  ebfh=create_struct(ebfh,'capacity',product(ebfh.dim256[0:ebfh.rank-1],/integer)*ebfh.datasize,'dataunit','','headersize',256L,'dim',ebfh.dim256[0:ebfh.rank-1])
  ebfh1=ebfh

  ebfh={endiantest:ebfh1.endiantest,headersize:256L,datatype:ebfh1.datatype,datasize:ebfh1.datasize,rank:ebfh1.rank,capacity:ebfh1.capacity,flags:bytarr(4),dim:ebfh1.dim,name:strlowcase(string(ebfh1.name)),dataunit:'',sdef:'',flagswap:ebfh1.flagswap}

end

pro ebfheader_read_V11,ebfh,lun
COMPILE_OPT STRICTARR,STRICTARRSUBS
ON_ERROR,2
    point_lun,-lun,headerpos
    ebfh1 = {sig:bytarr(8),version:bytarr(4),    $             
          endiantest:0L,headersize:0L,namesize:0L, $
          datatype:0L,datasize:0L, rank:0L,dataunit_size:0L,sdef_size:0L,flags:bytarr(4),capacity:0LL}
    readu,lun,ebfh1
    flagswap=0
    if ebfh1.endiantest ne  1684234849L then  begin
       swap_endian_inplace,ebfh1 
       flagswap=1
    endif   
    if ebfh1.endiantest ne  1684234849L then message,'Incorrect header format'

    if ebfh1.rank gt 0 then begin
       dim=lon64arr(ebfh1.rank)
       readu,lun,dim
       if flagswap eq 1 then swap_endian_inplace,dim
    endif else dim=1LL

    name=bytarr(ebfh1.namesize)
    readu,lun,name

    dataunit=""
    if ebfh1.dataunit_size gt 0 then begin
       dataunit=bytarr(ebfh1.dataunit_size)
       readu,lun,dataunit
       dataunit=string(dataunit)
    endif
    sdef=""
    if ebfh1.sdef_size gt 0 then begin
       sdef=bytarr(ebfh1.sdef_size)
       readu,lun,sdef
       sdef=string(sdef)
    endif

    ;; keyword=""
    ;; value=""
    ;; for i=0,ebfh1.nfields-1 do begin
    ;;    temp1=0b
    ;;    readu,lun,temp1    
    ;;    temp2=bytarr(temp1)
    ;;    readu,lun,temp2           
    ;;    keyword=[keyword,string(temp2)]
    ;;    temp1=0L
    ;;    readu,lun,temp1    
    ;;    if flagswap eq 1 then swap_endian_inplace,temp1
    ;;    temp2=bytarr(temp1)
    ;;    readu,lun,temp2           
    ;;    value=[value,string(temp2)]
    ;; endfor   
    point_lun,lun,headerpos+ebfh1.headersize
    point_lun,-lun,datapos
;    ebfh=create_struct(ebfh1,'dim',dim,'name',name,'dataunit',dataunit,'sdef',sdef,'flagswap',flagswap)

    ebfh={endiantest:ebfh1.endiantest,headersize:ebfh1.headersize,datatype:ebfh1.datatype,datasize:ebfh1.datasize,rank:ebfh1.rank,capacity:ebfh1.capacity,flags:ebfh1.flags,dim:dim,name:strlowcase(string(name)),dataunit:dataunit,sdef:sdef,flagswap:flagswap}
end




pro ebfheader_read,ebfh,lun
COMPILE_OPT STRICTARR,STRICTARRSUBS
ON_ERROR,2
    point_lun,-lun,pos
    sig=bytarr(12)
    readu,lun,sig
    point_lun,lun,pos    
    if(string(sig[0:2]) eq 'EBF') then begin
       ebfheader_read_V10,ebfh,lun
    endif else begin
       if (sig[8] eq 1)and(sig[9] eq 1) then begin 
          ebfheader_read_V11,ebfh,lun
       endif else begin
          message,'Unrecognized header'            
       endelse   
    endelse   
 end
