;----------------------------------------------------------------------------
;* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
;* Author: Sanjib Sharma                                                     *
;* Copyright (c) 2012 Sanjib Sharma                                          *
;* All rights reserved.                                                      *
;*                                                                           *
;* This file is part of EBF.  The full EBF copyright notice, including       *
;* terms governing use, modification, and redistribution, is contained in    *
;* the files COPYING and COPYRIGHT, which can be found at the root           *
;* of the source code distribution tree.                                     *
;* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
;-----------------------------------------------------------------------------
;+
;
; NAME:
;       EBFTABLE_CREATE
;
; PURPOSE: 
;       Internal use. To create a hashtable in an ebf file, for
;       locating data items. It creates /.ebf.htable in a file 
;       which already has /.ebf/info
; 
; CALLING SEQUENCE:
;       ebftable_create,lun,dinfo,dinfo_pos,dflagswap,header,hflagswap,capacity
;
; PARAMS:
;
; MODIFICATION HISTORY:
;       Written, 2013, Sanjib Sharma
;-

pro ebftable_create,lun,dinfo,dinfo_pos,dflagswap,header,hflagswap,capacity
  COMPILE_OPT STRICTARR,STRICTARRSUBS
  ON_ERROR,2
  header={version:bytarr(8),endiantest:1684234849LL,headersize:0LL,datatypesize:0LL,hash_algo:1LL,current:0LL,htcapacity:0LL,itemsize:0LL,itempos:0LL,itemcapacity:0LL,keypos:0LL,keycapacity:0LL,keyposcur:0LL}
  node={keyloc:0LL,keysize:0LL,value:0LL,next:0LL,tnext:0LL}

  header.version[0]=1
  header.endiantest=1684234849LL
  header.headersize=n_tags(header,/data_length)
  header.datatypesize=8
  header.hash_algo=1
  header.current=0
  header.itemsize=n_tags(node,/data_length)
  header.htcapacity=capacity+capacity/2
  header.itemcapacity=capacity
  header.keycapacity=20*header.itemcapacity
  header.itempos=header.headersize+header.datatypesize*header.htcapacity
  header.keypos=header.headersize+header.datatypesize*header.htcapacity+header.itemcapacity*header.itemsize
  header.keyposcur=0

  table=lon64arr(header.htcapacity)
  nodes=replicate(node,header.itemcapacity)


  tmp=fstat(lun)
  pos_end=tmp.size

; write htable  
  ebfheader_set,ebfh2,'/.ebf/htable',bytarr(header.keypos+header.keycapacity)
  ebfh2.datatype=9
  point_lun,lun,pos_end
  if hflagswap eq 1 then ebfh2.flagswap=1
  ebfheader_write,ebfh2,lun
  point_lun,-lun,offset
  if hflagswap then begin
     writeu,lun,swap_endian(header)
     writeu,lun,swap_endian(table)
     writeu,lun,swap_endian(nodes)
     writeu,lun,bytarr(header.keycapacity)
  endif else begin
     writeu,lun,header
     writeu,lun,table
     writeu,lun,nodes
     writeu,lun,bytarr(header.keycapacity)
  endelse
  point_lun,-lun,offset1

  dinfo[1]=pos_end
  dinfo[2]=offset
  dinfo[3]=1
  point_lun,lun,dinfo_pos
  if dflagswap eq 1 then begin
     writeu,lun,swap_endian(dinfo)
  endif else begin
     writeu,lun,dinfo
  endelse

  if (offset1-offset) ne ebfh2.capacity then begin
     print,'Ebf.Error FATAL in ebftable_create():'
     data=bytarr(offset1-offset2)
     ebfheader_set,ebfh2,'/.ebf/htable',bytarr(offset1-offset)
     point_lun,lun,pos_end
     ebfheader_write,ebfh2,lun
  endif


end
