;----------------------------------------------------------------------------
;* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
;* Author: Sanjib Sharma                                                     *
;* Copyright (c) 2012 Sanjib Sharma                                          *
;* All rights reserved.                                                      *
;*                                                                           *
;* This file is part of EBF.  The full EBF copyright notice, including       *
;* terms governing use, modification, and redistribution, is contained in    *
;* the files COPYING and COPYRIGHT, which can be found at the root           *
;* of the source code distribution tree.                                     *
;* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
;-----------------------------------------------------------------------------
;+
;
; NAME:
;       EBFTABLE_GET
;
; PURPOSE: 
;       Given a data name (key) get the location of the data in an ebf file.
;       
; CALLING SEQUENCE:
;       ebftable_get(filename,key)
;
; PARAMS:
;       fname : A string specifying the filename to write to.
;       key   : A string specifying the data name.
;
;
; EXTERNAL PROGRAMS USED:
;       ebftable_setup.pro
;
; MODIFICATION HISTORY:
;       Written, 2013, Sanjib Sharma
;-

function ebftable_get,fname,key1,VERSION=Version
  COMPILE_OPT STRICTARR,STRICTARRSUBS
  ON_ERROR,2
  Version='0.0.3'	
  key=strlowcase(key1)
  ebftable_setup,fname,lun,dinfo,dinfo_pos,dflagswap,header,hflagswap,ecode,/RONLY
  if ecode eq 0 then  begin
     ebftable_get_keyval,lun,dinfo,header,hflagswap,key,loc
  endif else begin
     if (size(dname))[0] eq 0 then loc=-1LL else loc=lon64arr(n_elements(key))
     if ecode lt 1000 then begin
        for i=0LL,n_elements(key)-1 do begin
           point_lun,lun,0L
           while ~EOF(lun) do begin
              point_lun,-lun,pos
              ebfheader_read,ebfh,lun
              if ebfh.name eq key[i] then begin 
                 loc[i]=pos
                 break
              endif
              point_lun,lun,pos+ebfh.capacity+ebfh.headersize
           endwhile 
        endfor
     endif
  endelse
  if n_elements(lun) ne 0 then free_lun,lun
  return,loc
end
