;----------------------------------------------------------------------------
;* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
;* Author: Sanjib Sharma                                                     *
;* Copyright (c) 2012 Sanjib Sharma                                          *
;* All rights reserved.                                                      *
;*                                                                           *
;* This file is part of EBF.  The full EBF copyright notice, including       *
;* terms governing use, modification, and redistribution, is contained in    *
;* the files COPYING and COPYRIGHT, which can be found at the root           *
;* of the source code distribution tree.                                     *
;* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
;-----------------------------------------------------------------------------
;+
;
; NAME:
;       EBFTABLE_INIT
;
; PURPOSE: 
;          Internal use. Creates an ebf file and writes /.ebf/info 
;          and /.ebf/htable which are needed for writing hashtable.   
;       
; CALLING SEQUENCE:
;       ebftable_init,filename,[VERSION=,SWAP=]
;
; KEYWORDS:
;
;       version: prints the version of the library in use. To be used 
;                to check if older version of dlm is being used or not. 
;
;       swap   : To create a file with ENDIAN-ness swapped from native
;                one.
;
; PARAMS:
;
;       filename : A string specifying the filename to write to.
;
;
; EXTERNAL PROGRAMS USED:
;       ebftable_put.pro, ebftable_create.pro:
;
; MODIFICATION HISTORY:
;       Written, 2013, Sanjib Sharma
;-

pro ebftable_init,fname,err,SWAP=Swap
  COMPILE_OPT STRICTARR,STRICTARRSUBS
  ON_ERROR,2
  openw,lun,fname,error=err,/get_lun ;,bufsize=1024l*1024l  
  if err ne 0 then begin 
     if n_elements(lun) ne 0 then free_lun,lun
     message,'Ebf error: cannot open file'
  endif else begin
     dinfo=lon64arr(5)
     ebfheader_set,ebfh,'/.ebf/info',dinfo

     if keyword_set(Swap) then begin
        ebfh.flagswap=1
        ebfheader_write,ebfh,lun
        point_lun,-lun,dinfo_pos
        writeu,lun,swap_endian(dinfo)
        ebftable_create,lun,dinfo,dinfo_pos,1,header,1,16        
     endif else begin
        ebfheader_write,ebfh,lun
        point_lun,-lun,dinfo_pos
        writeu,lun,dinfo
        ebftable_create,lun,dinfo,dinfo_pos,0,header,0,16
     endelse
     free_lun,lun
     keys=['/.ebf/info','/.ebf/htable']
     values=[0LL,dinfo[1]]
     ebftable_put,fname,keys,values
  endelse
end


