;----------------------------------------------------------------------------
;* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
;* Author: Sanjib Sharma                                                     *
;* Copyright (c) 2012 Sanjib Sharma                                          *
;* All rights reserved.                                                      *
;*                                                                           *
;* This file is part of EBF.  The full EBF copyright notice, including       *
;* terms governing use, modification, and redistribution, is contained in    *
;* the files COPYING and COPYRIGHT, which can be found at the root           *
;* of the source code distribution tree.                                     *
;* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
;-----------------------------------------------------------------------------
;+
;
; NAME:
;       EBFTABLE_REMOVE
;
; PURPOSE: 
;       Remove a data item from the hashtable of an ebf file. 
;       
; CALLING SEQUENCE:
;       ebftable_remove,filename,key
;
; PARAMS:
;       fname : A string specifying the filename to write to.
;       key   : A string specifying the data name.
;
;
; EXTERNAL PROGRAMS USED:
;       ebftable_setup.pro
;
; MODIFICATION HISTORY:
;       Written, 2013, Sanjib Sharma
;-

pro ebftable_remove,fname,key1
  COMPILE_OPT STRICTARR,STRICTARRSUBS
  ON_ERROR,2
  key=strlowcase(key1)
  ecode1=0
  ebftable_setup,fname,lun,dinfo,dinfo_pos,dflagswap,header,hflagswap,ecode
  if ecode eq 0 then begin
     keyhash=ebftable_ebflthash(key,header.htcapacity)
     loc1=ebftable_read_hvalue(lun,dinfo,header,hflagswap,keyhash)
     ecode1=1
     if loc1 ne 0 then begin
        item1=ebftable_read_node(lun,dinfo,header,hflagswap,loc1)
        if(ebftable_read_key(lun,dinfo,header,hflagswap,item1) eq key) then begin
           if item1.next eq -1 then temp=0LL else temp=long64(item1.next)
           ebftable_write_hvalue,lun,dinfo,header,hflagswap,keyhash,temp
           ecode1=0            
        endif else begin
           locp=-1LL
           locc=loc1 
           while (ebftable_read_key(lun,dinfo,header,hflagswap,item1) ne key) and (item1.next ne -1) do begin
              locp=locc        
              locc=item1.next        
              item1=ebftable_read_node(lun,dinfo,header,hflagswap,item1.next)                            
           endwhile
           if ebftable_read_key(lun,dinfo,header,hflagswap,item1) eq key then begin
              itemp=ebftable_read_node(lun,dinfo,header,hflagswap,locp)
              itemp.next=item1.next
              ebftable_write_node,lun,dinfo,header,hflagswap,locp, itemp
              ecode1=0            
           endif
        endelse
     endif
  endif
  if n_elements(lun) ne 0 then free_lun,lun
  if ecode ne 0 then message,"EBF: error in __remove(), ecode!=0"
  if ecode1 ne 0 then message,'EBF error: item to remove not found- '+fname+':'+key
end
